@@ -6,4 +6,9 @@ utils::globalVariables(c(".",
                          "Received",
                          "Accepted",
                          "tat",
-                         "issue_type"))
\ No newline at end of file
+                         "issue_type",
+                         "year_month",
+                         "mean_tat",
+                         "Revised",
+                         "open_peer_review"
+                         ))
\ No newline at end of file
